@@ -72,10 +72,8 @@ define(function(){
 
     // tree
     jglobal('SessionList','tree/js/sessionlist');
-    jglobal('ClusterList','tree/js/clusterlist');
-    jglobal('ClusterItem','tree/js/clusterlist');
 
-    Jupyter.version = "4.0.4";
+    Jupyter.version = "4.2.1";
     Jupyter._target = '_blank';
     return Jupyter;
 });
